/* cdf/cauchy.c
 * 
 * Copyright (C) 2003 Brian Gough
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <u.h>
#include <libc.h>
#include <stdio.h>
#include "../config.h"
#include "../gsl_types.h"
#include "../sys/gsl_sys.h"
#include "../gsl_machine.h"
#include "../gsl_precision.h"
#include "../gsl_nan.h"
#include "../gsl_pow_int.h"
#include "../gsl_math.h"
#include "../err/gsl_errno.h"
#include "../rng/gsl_rng.h"
#include "gsl_cdf.h"
#include "../specfunc/gsl_sf_result.h"
#include "../specfunc/gsl_sf_gamma.h"

double
gsl_cdf_cauchy_P (const double x, const double a)
{
  double P;
  double u = x / a;

  if (u > -1)
    {
      P = 0.5 + atan (u) / M_PI;
    }
  else
    {
      P = atan(-1/u) / M_PI;
    }
  
  return P;
}

double
gsl_cdf_cauchy_Q (const double x, const double a)
{
  double Q;
  double u = x / a;
  
  if (u < 1)
    {
      Q = 0.5 - atan (u) / M_PI;
    }
  else
    {
      Q = atan(1/u) / M_PI;
    }

  return Q;
}
