/* randist/pareto.c
 * 
 * Copyright (C) 1996, 1997, 1998, 1999, 2000 James Theiler, Brian Gough
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <u.h>
#include <libc.h>
#include <stdio.h>
#include "../config.h"
#include "../gsl_types.h"
#include "../sys/gsl_sys.h"
#include "../gsl_machine.h"
#include "../gsl_precision.h"
#include "../gsl_nan.h"
#include "../gsl_pow_int.h"
#include "../gsl_math.h"
#include "../err/gsl_errno.h"
#include "../rng/gsl_rng.h"
#include "gsl_randist.h"
#include "../specfunc/gsl_sf_result.h"
#include "../specfunc/gsl_sf_gamma.h"
#include "../specfunc/gsl_sf_erf.h"

/* The Pareto distribution has the form,

   p(x) dx = (a/b) / (x/b)^(a+1) dx     for x >= b

 */

double
gsl_ran_pareto (const gsl_rng * r, double a, const double b)
{
  double x = gsl_rng_uniform_pos (r);

  double z = pow (x, -1 / a);

  return b * z;
}

double
gsl_ran_pareto_pdf (const double x, const double a, const double b)
{
  if (x >= b)
    {
      double p = (a/b) / pow (x/b, a + 1);
      return p;
    }
  else
    {
      return 0;
    }
}

