/* sys/infnan.c
 * 
 * Copyright (C) 2001, 2004 Brian Gough
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <u.h>
#include <libc.h>
#include <stdio.h>
#include "../config.h"
#include "../sys/gsl_sys.h"
#include "../gsl_machine.h"

double gsl_nan (void);
double gsl_posinf (void);
double gsl_neginf (void);
double gsl_fdiv (const double x, const double y);

double gsl_nan (void)
{
  return gsl_fdiv (0.0, 0.0);
}

double gsl_posinf (void)
{
  return gsl_fdiv (+1.0, 0.0);
}

double gsl_neginf (void)
{
  return gsl_fdiv (-1.0, 0.0);
}


int gsl_isnan (const double x);
int gsl_isinf (const double x);
int gsl_finite (const double x);

#ifdef HAVE_IEEE_COMPARISONS
int
gsl_isnan (const double x)
{
  int status = (x != x);
  return status;
}

int
gsl_isinf (const double x)
{
  double y = x - x;
  int s = (y != y);

  if (s && x > 0)
    return +1;
  else if (s && x < 0)
    return -1;
  else
    return 0;
}

int
gsl_finite (const double x)
{
  const double y = x - x;
  int status = (y == y);
  return status;
}
#else

#ifdef HAVE_DECL_ISNAN
int
gsl_isnan (const double x)
{
  return isnan(x);
}
#endif

#ifdef HAVE_DECL_ISINF
int
gsl_isinf (const double x)
{
    return isinf(x);
}
#else
int
gsl_isinf (const double x)
{
    return (! gsl_finite(x)) && (! gsl_isnan(x));
}
#endif


#ifdef HAVE_DECL_FINITE
int
gsl_finite (const double x)
{
  return finite(x);
}
#else 
#ifdef HAVE_DECL_ISFINITE
int
gsl_finite (const double x)
{
  return isfinite(x);
}
#endif

#endif

